library(ggplot2)

# Sample data for 6 groups (replace with your actual data)
Group1 <- c(508,279,504,350,381,137,535,380,107,196,202,239)
Group2 <- c(368,245,143,70,74,149,116,69,229,158,191,275)
Group3 <- c(170,140,128,150,190,142,285,178,209,228,172,169)
Group4 <- c(67,103,78,73,179,201,96,147,125,144,242,131)
Group5 <- c(156,223,195,508,549,240,441,138,338,222,475,542)
Group6 <- c(143,266,164,144,233,207,229,126,133,140,232,188)

# Combine data into a single data frame
data <- data.frame(
  Group = factor(rep(1:6, each = 12)),
  Value = c(Group1, Group2, Group3, Group4, Group5, Group6)
)

# Create a grouped boxplot using ggplot2
p <- ggplot(data, aes(x = Group, y = Value, fill = as.factor(Group))) +
  geom_boxplot(show.legend = FALSE) +
  theme_bw() +
  labs(x = "Different task", y = "Navigation time(s)") +
  scale_fill_manual(values = c("#63AEF4", "#61D9AC", "#63AEF4", "#61D9AC", "#63AEF4", "#61D9AC"))+
  theme(panel.grid = element_blank(),
        panel.border = element_rect(fill=NA,linewidth = 1.5),
        plot.margin = unit(c(1,1,1,1),"cm",)
  )

# Change the x-axis labels and add dashed lines
p2 <- p + scale_x_discrete(labels = c("task1", "task1", "task2", "task2", "task3", "task3"))+
  geom_vline(xintercept = c(2.5, 4.5), linetype = "dashed", color = "black", size = 0.5)+
  
  annotate("rect", xmin = 5.5, xmax = 6.6, ymin = max(data$Value) - 10, ymax = max(data$Value)+80, fill = "transparent", color = "black")+
  annotate("rect", xmin = 5.56, xmax = 5.68, ymin = max(data$Value)+40, ymax = max(data$Value)+60, fill = "#63AEF4", color = "black")+
  annotate("text", x = 6.15, y = max(data$Value)+50, label = "Ipsmap", size = 2.5, color = "black")+
  annotate("rect", xmin = 5.56, xmax = 5.68, ymin = max(data$Value)+5, ymax = max(data$Value)+25, fill = "#61D9AC", color = "black")+
  annotate("text", x = 6.15, y = max(data$Value)+15, label = "Prototype map", size = 2.5, color = "black")+
  
  annotate("rect", xmin = 0.9, xmax = 1.1, ymin = max(Group1), ymax = max(Group1)+0.1, fill = "black", color = "black")+
  annotate("rect", xmin = 0.9, xmax = 1.1, ymin = min(Group1), ymax = min(Group1)+0.1, fill = "black", color = "black")+
  annotate("rect", xmin = 1.9, xmax = 2.1, ymin = max(Group2), ymax = max(Group2)+0.1, fill = "black", color = "black")+
  annotate("rect", xmin = 1.9, xmax = 2.1, ymin = min(Group2), ymax = min(Group2)+0.1, fill = "black", color = "black")+
  annotate("rect", xmin = 2.9, xmax = 3.1, ymin = 228, ymax = 228.1, fill = "black", color = "black")+
  annotate("rect", xmin = 2.9, xmax = 3.1, ymin = min(Group3), ymax = min(Group3)+0.1, fill = "black", color = "black")+
  annotate("rect", xmin = 3.9, xmax = 4.1, ymin = max(Group4), ymax = max(Group4)+0.1, fill = "black", color = "black")+
  annotate("rect", xmin = 3.9, xmax = 4.1, ymin = min(Group4), ymax = min(Group4)+0.1, fill = "black", color = "black")+
  annotate("rect", xmin = 4.9, xmax = 5.1, ymin = max(Group5), ymax = max(Group5)+0.1, fill = "black", color = "black")+
  annotate("rect", xmin = 4.9, xmax = 5.1, ymin = min(Group5), ymax = min(Group5)+0.1, fill = "black", color = "black")+
  annotate("rect", xmin = 5.9, xmax = 6.1, ymin = max(Group6), ymax = max(Group6)+0.1, fill = "black", color = "black")+
  annotate("rect", xmin = 5.9, xmax = 6.1, ymin = min(Group6), ymax = min(Group6)+0.1, fill = "black", color = "black")

p2

#使用ggsave保存图表
ggsave("my_plot.png", plot = p2, width = 6, height = 4, dpi = 300)

